==> nextcloud-12.0.5.tar.bz2: nextcloud/apps/files/l10n/uk.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Сховище тимчасово недоступне",
    "Storage invalid" : "Невірне сховище",
    "Unknown error" : "Невідома помилка",
    "All files" : "Усі файли",
    "Recent" : "Останні",
    "File could not be found" : "Файл не знайдено",
    "Home" : "Домівка",
    "Close" : "Закрити",
    "Favorites" : "Улюблені",
    "Could not create folder \"{dir}\"" : "Неможливо створити каталог \"{dir}\"",
    "Upload cancelled." : "Вивантаження скасовано.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Неможливо вивантажити {filename}, оскільки це каталог або файл має розмір 0 байт.",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Недостатньо вільного місця, ви вивантажуєте {size1}, а залишилося лише {size2}",
    "Target folder \"{dir}\" does not exist any more" : "Теки призначення \"{dir}\" більше не існує.",
    "Not enough free space" : "Недостатньо вільного місця",
    "…" : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} з {totalSize} ({bitrate})",
    "Actions" : "Дії",
    "Download" : "Завантажити",
    "Rename" : "Перейменувати",
    "Move or copy" : "Перенести або копіювати",
    "Target folder" : "Тека призначення",
    "Delete" : "Видалити",
    "Disconnect storage" : "Від’єднати сховище",
    "Unshare" : "Закрити спільний доступ",
    "Could not load info for file \"{file}\"" : "Неможливо завантажити інформацію за файлом \"{file}\"",
    "Files" : "Файли",
    "Details" : "Деталі",
    "Select" : "Оберіть",
    "Pending" : "Очікування",
    "Unable to determine date" : "Неможливо визначити дату",
    "This operation is forbidden" : "Ця операція заборонена",
    "This directory is unavailable, please check the logs or contact the administrator" : "Директорія недоступна, будь ласка, перевірте файл журналу або зверніться до адміністратора  ",
    "Could not move \"{file}\"" : "Неможливо перемістити файл \"{file}\"",
    "Could not copy \"{file}\"" : "Неможливо скопіювати \"{file}\"",
    "Copied {origin} inside {destination}" : "Скопійовано {origin} до {destination}",
    "{newName} already exists" : "{newName} вже існує",
    "Could not rename \"{fileName}\", it does not exist any more" : "Неможливо перейменувати \"{fileName}\", він більше не існує",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Ім'ґ \"{targetName}\" вже використовується в каталозі \"{dir}\". Будь-ласка, виберіть іншу назву.",
    "Could not rename \"{fileName}\"" : "Неможливо перейменувати \"{fileName}\"",
    "Could not create file \"{file}\"" : "Неможливо створити файл \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Неможливо створити файл \"{file}\", оскільки він вже існує.",
    "Could not create folder \"{dir}\" because it already exists" : "Неможливо створити каталог \"{dir}\", оскільки він вже існує.",
    "Error deleting file \"{fileName}\"." : "Помилка видалення файлу \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Нічого не знайдено в інших каталогах за запитом {tag}{filter}{endtag}",
    "Name" : "Ім'я",
    "Size" : "Розмір",
    "Modified" : "Змінено",
    "_%n folder_::_%n folders_" : ["%n тека ","теки : %n ","теки : %n "],
    "_%n file_::_%n files_" : ["%n файл ","файли : %n ","файли : %n "],
    "{dirs} and {files}" : "{dirs} і {files}",
    "You don’t have permission to upload or create files here" : "У вас недостатньо прав для вивантаження або створення тут файлів",
    "_Uploading %n file_::_Uploading %n files_" : ["Вивантаження %n файлу","Вивантаження %n файлів","Вивантаження %n файлів"],
    "New" : "Створити",
    "\"{name}\" is an invalid file name." : "\"{name}\" - некоректне ім'я файлу.",
    "File name cannot be empty." : " Ім'я файлу не може бути порожнім.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" є недопустимим типом файлу",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Сховище користувача {owner} переповнене, файли більше не можуть бути оновлені або синхронізовані!",
    "Your storage is full, files can not be updated or synced anymore!" : "Ваше сховище переповнене, файли більше не можуть бути оновлені або синхронізовані !",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Сховище користувача {owner} майже заповнене ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Ваше сховище майже повне ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["знайдено '{filter}'","знайдено '{filter}'","знайдено '{filter}'"],
    "View in folder" : "Переглянути в каталозі",
    "Copied!" : "Скопійовано!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Скопіювати пряме посилання (працює лише для користувачів, що мають доступ до файлу/теки)",
    "Path" : "Шлях",
    "Favorited" : "Улюблений",
    "Favorite" : "Улюблений",
    "New folder" : "Нова тека",
    "Upload file" : "Вивантажити файл",
    "Remove from favorites" : "Видалено з улюбленого",
    "Add to favorites" : "Додати до улюбленого",
    "An error occurred while trying to update the tags" : "Виникла помилка при спробі оновити мітки",
    "Added to favorites" : "Додано до улюбленого",
    "Removed from favorites" : "Видалено з улюбленого",
    "You added {file} to your favorites" : "Ви додали {file} до вашого улюбленого",
    "You removed {file} from your favorites" : "Ви видалили {file} з улюбленого",
    "File changes" : "Зміни файлу",
    "Created by {user}" : "Створено користувачем {user}",
    "Changed by {user}" : "Змінено користувачем {user}",
    "Deleted by {user}" : "Видалено користувачем {user}",
    "Restored by {user}" : "Відновлено користувачем {user}",
    "Renamed by {user}" : "Перейменовано користувачем {user}",
    "Moved by {user}" : "Переміщено користувачем {user}",
    "\"remote user\"" : "\"віддалений користувач\"",
    "You created {file}" : "Ви створили {file}",
    "{user} created {file}" : "Користувач {user} створив {file}",
    "{file} was created in a public folder" : "Файл {file} створено у спільній теці",
    "You changed {file}" : "Ви змінили {file}",
    "{user} changed {file}" : "Користувач {user} змінив {file}",
    "You deleted {file}" : "Ви видалили {file}",
    "{user} deleted {file}" : "Користувач {user} видалив {file}",
    "You restored {file}" : "Ви відновили {file}",
    "{user} restored {file}" : "Користувач {user} відновив {file}",
    "You renamed {oldfile} to {newfile}" : "Ви перейменували {oldfile} в {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "Користувач {user} перейменував {oldfile} у {newfile}",
    "You moved {oldfile} to {newfile}" : "Ви перемістили {oldfile} до {newfile}",
    "{user} moved {oldfile} to {newfile}" : "Користувач {user} перемістив {oldfile} до {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Файл був доданий до або або вилучений з вашого <strong>улюбленого</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Файл або теку було <strong>змінено</strong> або <strong>перейменовано</strong>",
    "A new file or folder has been <strong>created</strong>" : "Новий файл або теку було <strong>створено</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Файл або теку було <strong> видалено </strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Обмежити повідомлення про створення та зміни в ваших <strong>улюблених файлах</strong>\n<em>(Тількі потік)</em>",
    "A file or folder has been <strong>restored</strong>" : "Файл або теку було <strong> відновлено </strong>",
    "Unlimited" : "Необмежено",
    "Upload (max. %s)" : "Вивантаження (макс. %s)",
    "File handling" : "Робота з файлами",
    "Maximum upload size" : "Максимальний розмір вивантажень",
    "max. possible: " : "макс. можливе:",
    "Save" : "Зберегти",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "З PHP-FPM прийняття змін може тривати до 5 хвилин.",
    "Missing permissions to edit from here." : "Недостатньо прав для редагування звідси.",
    "%s of %s used" : "%s з %s використано",
    "%s used" : "%s використано",
    "Settings" : "Налаштування",
    "Show hidden files" : "Показати приховані файли",
    "WebDAV" : "WebDAV",
    "No files in here" : "Тут немає файлів",
    "Upload some content or sync with your devices!" : "Вивантажте щось або синхронізуйте з пристроями!",
    "No entries found in this folder" : "В цій теці нічого немає",
    "Select all" : "Вибрати всі",
    "Upload too large" : "Файл занадто великий",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Файли,що ви намагаєтесь вивантажити перевищують максимальний дозволений розмір файлів на цьому сервері.",
    "No favorites yet" : "Ще немає улюблених",
    "Files and folders you mark as favorite will show up here" : "Файли і теки, які ви позначили як улюблені, з’являться тут",
    "Shared with you" : "Поділились з вами",
    "Shared with others" : "Поділились з іншими",
    "Shared by link" : "Доступне за посиланням",
    "Tags" : "Теги",
    "Deleted files" : "Видалені файли",
    "Text file" : "Текстовий файл",
    "New text file.txt" : "Новий текстовий файл file.txt",
    "Uploading..." : "Вивантаження...",
    "..." : "...",
    "{hours}:{minutes}h" : "{hours}:{minutes} год",
    "{seconds}s" : "{seconds} сек",
    "Any moment now..." : "В будь-який момент...",
    "Soon..." : "Незабаром...",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Виконується вивантаження файлу. Закриття цієї сторінки приведе до скасування вивантаження.",
    "Move" : "Перемістити",
    "Copy local link" : "Копіювати посилання",
    "Folder" : "Тека",
    "Upload" : "Вивантажити",
    "A new file or folder has been <strong>deleted</strong>" : "Новий файл або теку було <strong>видалено</strong>",
    "A new file or folder has been <strong>restored</strong>" : "Новий файл або теку було <strong>відновлено</strong>",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Використайте цю адресу для <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">доступу через WebDAV</a>",
    "No favorites" : "Немає улюблених"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-15.0.10.tar.bz2: nextcloud/apps/files/l10n/uk.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Сховище тимчасово недоступне",
    "Storage invalid" : "Невірне сховище",
    "Unknown error" : "Невідома помилка",
    "All files" : "Усі файли",
    "Recent" : "Останні",
    "Favorites" : "Улюблені",
    "File could not be found" : "Неможливо знайти файл",
    "Move or copy" : "Перенести або копіювати",
    "Download" : "Завантажити",
    "Delete" : "Видалити",
    "Home" : "Домівка",
    "Close" : "Закрити",
    "Could not create folder \"{dir}\"" : "Неможливо створити каталог \"{dir}\"",
    "This will stop your current uploads." : "Ця дія призведе до зупинки поточних завантажень на сервер.",
    "Upload cancelled." : "Вивантаження скасовано.",
    "Processing files …" : "Обробка файлів ...",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Неможливо вивантажити {filename}, оскільки це каталог або файл має розмір 0 байт.",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Недостатньо вільного місця, ви вивантажуєте {size1}, а залишилося лише {size2}",
    "Target folder \"{dir}\" does not exist any more" : "Теки призначення \"{dir}\" більше не існує.",
    "Not enough free space" : "Недостатньо вільного місця",
    "An unknown error has occurred" : "Сталася невідома помилка",
    "Uploading …" : "Вивантаження …",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} з {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Завантаження цього елемента не підтримується",
    "Target folder does not exist any more" : "Цільовий каталог більше не існує",
    "Error when assembling chunks, status code {status}" : "Помилка під час збірки частин, код помилки {status}",
    "Actions" : "Дії",
    "Rename" : "Перейменувати",
    "Copy" : "Скопіювати",
    "Choose target folder" : "Виберіть цільовий каталог",
    "Open" : "Відкрити",
    "Disconnect storage" : "Від’єднати сховище",
    "Unshare" : "Закрити доступ",
    "Could not load info for file \"{file}\"" : "Не вдалося завантажити інформацію для файлу \"{file}\"",
    "Files" : "Файли",
    "Details" : "Деталі",
    "Select" : "Вибрати",
    "Pending" : "Очікування",
    "Unable to determine date" : "Неможливо визначити дату",
    "This operation is forbidden" : "Ця операція заборонена",
    "This directory is unavailable, please check the logs or contact the administrator" : "Директорія недоступна, будь ласка, перевірте файл журналу або зверніться до адміністратора  ",
    "Could not move \"{file}\", target exists" : "Не вдається перемістити файл \"{file}\", він вже існує в точці призначення",
    "Could not move \"{file}\"" : "Неможливо перемістити файл \"{file}\"",
    "copy" : "копія",
    "Could not copy \"{file}\", target exists" : "Не вдається скопіювати файл \"{file}\", він вже існує в точці призначення",
    "Could not copy \"{file}\"" : "Неможливо скопіювати \"{file}\"",
    "Copied {origin} inside {destination}" : "Скопійовано {origin} до {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} ті {nbfiles} інших файлів скопійовано в {destination}",
    "{newName} already exists" : "{newName} вже існує",
    "Could not rename \"{fileName}\", it does not exist any more" : "Неможливо перейменувати \"{fileName}\", він більше не існує",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Ім'я \"{targetName}\" вже використовується в каталозі \"{dir}\". Будь-ласка, виберіть іншу назву.",
    "Could not rename \"{fileName}\"" : "Неможливо перейменувати \"{fileName}\"",
    "Could not create file \"{file}\"" : "Неможливо створити файл \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Неможливо створити файл \"{file}\", оскільки він вже існує.",
    "Could not create folder \"{dir}\" because it already exists" : "Неможливо створити каталог \"{dir}\", оскільки він вже існує.",
    "Error deleting file \"{fileName}\"." : "Помилка видалення файлу \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Нічого не знайдено в інших каталогах за запитом {tag}{filter}{endtag}",
    "Name" : "Ім'я",
    "Size" : "Розмір",
    "Modified" : "Змінено",
    "_%n folder_::_%n folders_" : ["%n тека ","теки : %n ","теки : %n ","теки : %n "],
    "_%n file_::_%n files_" : ["%n файл ","файли : %n ","файли : %n ","файли : %n "],
    "{dirs} and {files}" : "{dirs} і {files}",
    "_including %n hidden_::_including %n hidden_" : ["включаючи %n прихований","включаючи %n прихованих","включаючи %n прихованих","включаючи %n прихованих"],
    "You don’t have permission to upload or create files here" : "У вас недостатньо прав для вивантаження або створення тут файлів",
    "_Uploading %n file_::_Uploading %n files_" : ["Вивантаження %n файлу","Вивантаження %n файлів","Вивантаження %n файлів","Вивантаження %n файлів"],
    "New" : "Створити",
    "Select file range" : "Виберіть набір файлів",
    "{used} of {quota} used" : "використано {used} з {quota}",
    "{used} used" : "використано {used}",
    "\"{name}\" is an invalid file name." : "\"{name}\" - некоректне ім'я файлу.",
    "File name cannot be empty." : " Ім'я файлу не може бути порожнім.",
    "\"/\" is not allowed inside a file name." : "Символ \"/\" не дозволений в іменах файлів.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" є недопустимим типом файлу",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Сховище користувача {owner} переповнене, файли більше не можуть бути оновлені або синхронізовані!",
    "Your storage is full, files can not be updated or synced anymore!" : "Ваше сховище переповнене, файли більше не можуть бути оновлені або синхронізовані !",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Сховище користувача {owner} майже заповнене ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Ваше сховище майже повне ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["знайдено '{filter}'","знайдено '{filter}'","знайдено '{filter}'","знайдено '{filter}'"],
    "View in folder" : "Переглянути в каталозі",
    "Copied!" : "Скопійовано!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Скопіювати пряме посилання (працює лише для користувачів, що мають доступ до файлу/теки)",
    "Path" : "Шлях",
    "_%n byte_::_%n bytes_" : ["%n байт","%n байти","%n байт","%n байт"],
    "Favorited" : "Улюблений",
    "Favorite" : "В улюблене",
    "You can only favorite a single file or folder at a time" : "Одночасно вподобати можна лише один файл чи каталог",
    "New folder" : "Нова тека",
    "Upload file" : "Вивантажити файл",
    "Not favorited" : "Не улюблене",
    "Remove from favorites" : "Видалено з улюбленого",
    "Add to favorites" : "Додати до улюбленого",
    "An error occurred while trying to update the tags" : "Виникла помилка при спробі оновити мітки",
    "Added to favorites" : "Додано до улюбленого",
    "Removed from favorites" : "Видалено з улюбленого",
    "You added {file} to your favorites" : "Ви додали {file} до вашого улюбленого",
    "You removed {file} from your favorites" : "Ви видалили {file} з улюбленого",
    "File changes" : "Зміни файлу",
    "Created by {user}" : "Створено користувачем {user}",
    "Changed by {user}" : "Змінено користувачем {user}",
    "Deleted by {user}" : "Видалено користувачем {user}",
    "Restored by {user}" : "Відновлено користувачем {user}",
    "Renamed by {user}" : "Перейменовано користувачем {user}",
    "Moved by {user}" : "Переміщено користувачем {user}",
    "\"remote user\"" : "\"віддалений користувач\"",
    "You created {file}" : "Ви створили {file}",
    "You created an encrypted file in {file}" : "Ви створили зашифрований файл у {file}",
    "{user} created {file}" : "Користувач {user} створив {file}",
    "{user} created an encrypted file in {file}" : "{user} створив зашифрований файл у {file}",
    "{file} was created in a public folder" : "Файл {file} створено у спільній теці",
    "You changed {file}" : "Ви змінили {file}",
    "You changed an encrypted file in {file}" : "Ви змінили зашифрований файл у {file}",
    "{user} changed {file}" : "Користувач {user} змінив {file}",
    "{user} changed an encrypted file in {file}" : "{user} змінив зашифрований файл у {file}",
    "You deleted {file}" : "Ви видалили {file}",
    "You deleted an encrypted file in {file}" : "Ви вилучити зашифрований файл у {file}",
    "{user} deleted {file}" : "Користувач {user} видалив {file}",
    "{user} deleted an encrypted file in {file}" : "{user} вилучив зашифрований файл у {file}",
    "You restored {file}" : "Ви відновили {file}",
    "{user} restored {file}" : "Користувач {user} відновив {file}",
    "You renamed {oldfile} to {newfile}" : "Ви перейменували {oldfile} в {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "Користувач {user} перейменував {oldfile} у {newfile}",
    "You moved {oldfile} to {newfile}" : "Ви перемістили {oldfile} до {newfile}",
    "{user} moved {oldfile} to {newfile}" : "Користувач {user} перемістив {oldfile} до {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Файл був доданий до або або вилучений з вашого <strong>улюбленого</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Файл або теку було <strong>змінено</strong> або <strong>перейменовано</strong>",
    "A new file or folder has been <strong>created</strong>" : "Новий файл або теку було <strong>створено</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Файл або теку було <strong> видалено </strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Обмежити повідомлення про створення та зміни в ваших <strong>улюблених файлах</strong>\n<em>(Тількі потік)</em>",
    "A file or folder has been <strong>restored</strong>" : "Файл або теку було <strong> відновлено </strong>",
    "Unlimited" : "Необмежено",
    "Upload (max. %s)" : "Вивантаження (макс. %s)",
    "File Management" : "Управління файлами",
    "%s used" : "%s використано",
    "%1$s of %2$s used" : "використано %1$s з %2$s",
    "Settings" : "Налаштування",
    "Show hidden files" : "Показати приховані файли",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Використовуйте цю адресу для <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">доступ до своїх файлів через WebDAV</a>",
    "Toggle grid view" : "Показати плитками",
    "No files in here" : "Тут немає файлів",
    "Upload some content or sync with your devices!" : "Вивантажте щось або синхронізуйте з пристроями!",
    "No entries found in this folder" : "В цій теці нічого немає",
    "Select all" : "Вибрати всі",
    "Upload too large" : "Файл занадто великий",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Файли,що ви намагаєтесь вивантажити перевищують максимальний дозволений розмір файлів на цьому сервері.",
    "No favorites yet" : "Ще немає улюблених",
    "Files and folders you mark as favorite will show up here" : "Файли і теки, які ви позначили як улюблені, з’являться тут",
    "Tags" : "Теги",
    "Deleted files" : "Видалені файли",
    "Shares" : "Спільний доступ",
    "Shared with others" : "Поділились з іншими",
    "Shared with you" : "Поділились з вами",
    "Shared by link" : "Доступне за посиланням",
    "Deleted shares" : "Вилучено зі спільного доступу",
    "Text file" : "Текстовий файл",
    "New text file.txt" : "Новий текстовий файл file.txt",
    "Target folder" : "Тека призначення",
    "File handling" : "Робота з файлами",
    "Maximum upload size" : "Максимальний розмір вивантажень",
    "max. possible: " : "макс. можливе:",
    "Save" : "Зберегти",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "З PHP-FPM прийняття змін може тривати до 5 хвилин.",
    "Missing permissions to edit from here." : "Недостатньо прав для редагування звідси.",
    "%s of %s used" : "%s з %s використано",
    "Cancel upload" : "Скасувати завантаження",
    "%1$s%% of %2$s used" : "використано %1$s%% з %2$s"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
